<xsl:stylesheet 
  version="1.0" 
  exclude-result-prefixes="x d xsl msxsl cmswrt"
  xmlns:x="http://www.w3.org/2001/XMLSchema" 
  xmlns:d="http://schemas.microsoft.com/sharepoint/dsp" 
  xmlns:cmswrt="http://schemas.microsoft.com/WebParts/v3/Publishing/runtime"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:ddwrt="http://schemas.microsoft.com/WebParts/v2/DataView/runtime">    
 
	<xsl:template name="removeMarkup">
		<xsl:param name="string" />
		<xsl:choose>
			<xsl:when test="contains($string, '&lt;')">
				<xsl:variable name="nextString">
					<xsl:call-template name="removeMarkup">
						<xsl:with-param name="string" select="substring-after($string, '&gt;')" />
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="concat(substring-before($string, '&lt;'), $nextString)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$string" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	

<!-- Item styles for Neuroscience TA -->

	<xsl:template name="NeuroTANewsStyle" match="Row[@Style='NeuroTANewsStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/neuroscienceta',$SafeLinkUrl,'&amp;source=/neuroscienceta/Pages/Home.aspx')" />
		</xsl:variable>
        
		<div id="BiotechnewsStyle" class="pcd">        
			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" class="titel">
				<xsl:value-of select="$DisplayTitle"/>
			</a>   	         
		</div>
	</xsl:template>


	<xsl:template name="NeuroTATopNewsStyle" match="Row[@Style='NeuroTATopNewsStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeLargeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'LargeImage'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/NeuroscienceTA',$SafeLinkUrl,'&amp;source=/NeuroscienceTA/Pages/Home.aspx')" />
		</xsl:variable>
        
		<table cellpadding="4" width="100%">

			<tr>
			<td align="center">

			<xsl:if test="string-length($SafeLargeImageUrl) != 0">
				<div id="newswrapper-feature" class="news-wrapper">
					<a href="{$back}" target="{$LinkTarget}" class="img">
						<img class="image" width="405" height="232" src="{$SafeLargeImageUrl}" alt="{@LargeImageAltText}" />
					</a>
					<a href="{$back}" target="{$LinkTarget}"><div class="news-trans-background"><span style="font-size: 11px;"><b><xsl:value-of select="$DisplayTitle"/></b><br /><xsl:value-of select="substring($Article, 0, 120)" disable-output-escaping="yes" />... read more</span></div></a>
				</div>
			</xsl:if>

			<xsl:if test="string-length($SafeLargeImageUrl) = 0">
				<div id="newswrapper-feature" class="news-wrapper">
					<a href="{$back}" target="{$LinkTarget}" class="img">
						<img class="image" width="405" height="232" src="http://pharmarnd.jnj.com/NeuroscienceTA/PublishingImages/Chrome/default-featured-news-image.jpg" alt="Default Image" />
					</a>
					<a href="{$back}" target="{$LinkTarget}"><div class="news-trans-background"><span style="font-size: 11px;"><b><xsl:value-of select="$DisplayTitle"/></b><br /><xsl:value-of select="substring($Article, 0, 120)" disable-output-escaping="yes" />... read more</span></div></a>
				</div>
			</xsl:if>

			</td>
			</tr>

		</table> 

	</xsl:template>

	<xsl:template name="NeuroscienceHappeningStyle2" match="Row[@Style='NeuroscienceHappeningStyle2']" mode="itemstyle">
        
		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>

		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>   

		<xsl:variable name="DateM">
 			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MMM')" />
		</xsl:variable>

		<xsl:variable name="DateD">
 			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'dd')" />
		</xsl:variable>

		<div id="happeningStyle">
			<table>
				<tr>
				<td valign="top" class="happeningDIV2" height="61px">

				<p class="clearfix">
				<span class="maand2"><xsl:value-of select="$DateM"/></span>
				<span class="dag2"><xsl:value-of select="$DateD"/></span>
				<a href="{$SafeLinkUrl}" target="{$LinkTarget}" title="{@LinkToolTip}" style="color:black;">
					<xsl:value-of select="$DisplayTitle"/>
				</a>
				<xsl:value-of select="@Location"/>
				</p>
				</td>
				</tr>
			</table>
		</div>

	</xsl:template>


	<xsl:template name="NeuroPeopleHomeStyle" match="Row[@Style='NeuroPeopleHomeStyle']" mode="itemstyle">
        
		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>

		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>  
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="back">
			<xsl:value-of select="concat('/NeuroscienceTA',$SafeLinkUrl,'&amp;source=/NeuroscienceTA/Pages/Home.aspx')" />
		</xsl:variable>

		<xsl:variable name="Bio">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Job">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@JobTitle"/>
			</xsl:call-template>
		</xsl:variable>
    	
		<table id="PMOboardStyle" class="QSPeopleHomeDIV">
			<tr>
			<td valign="top">

			<xsl:if test="string-length($SafeImageUrl) != 0"> 
				<a href="{$back}" target="{$LinkTarget}">
					<img class="image" src="{$SafeImageUrl}" alt="{@ImageUrlAltText}" width="37" height="34" border="0" />
				</a>
			</xsl:if>

			<xsl:if test="string-length($SafeImageUrl) = 0"> 
				<a href="{$back}" target="{$LinkTarget}">
					<img class="image" src="NeuroscienceTA/PublishingImages/Chrome/People_icon.png" alt="Default Image" width="37" height="34" border="0" />
				</a>
			</xsl:if>

			</td><td valign="top">

			<a href="{$back}" target="{$LinkTarget}"><b><xsl:value-of select="$DisplayTitle"/></b></a>
			<br />
			<xsl:value-of select="$Job" disable-output-escaping="yes" />
			</td>
			</tr>
		</table>

	</xsl:template>


	<xsl:template name="videoStyle" match="Row[@Style='videoStyle']" mode="itemstyle"> 

		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="URL">
			<xsl:value-of select="substring-before(@URL,',')"/>
		</xsl:variable>

		<div id="vidoeStyle" class="videoDIV" style="margin-left:0px;">

			<table class="videoDIV">
				<tr>
				<td valign="top">
				<xsl:if test="string-length($SafeImageUrl) != 0"> 
					<img class="image" style="margin-left:0px;" src="{$SafeImageUrl}" width="86" height="66"/>
				</xsl:if>
				<xsl:if test="string-length($SafeImageUrl) = 0"> 
					<img class="image" style="margin-left:0px;" src="NeuroscienceTA/PublishingImages/Chrome/project1.gif" width="86" height="66"/>
				</xsl:if>

				</td><td valign="top">

				<a href="{$URL}" target="_blank">
					<xsl:value-of select="$DisplayTitle"/>
				</a>

				<xsl:value-of select="@Duration"/>
				</td>
				</tr>
			</table>

		</div>

	</xsl:template>


	<xsl:template name="NeuroTACommunityStyle" match="Row[@Style='NeuroTACommunityStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/neuroscienceta',$SafeLinkUrl,'&amp;source=/neuroscienceta/Pages/Home.aspx')" />
		</xsl:variable>

		<xsl:variable name="tableOpen">&lt;table cellpadding=10 cellspacing=0 border=0&gt;&lt;tr&gt;&lt;td valign=&quot;top&quot;&gt;&lt;img src=&quot;NeuroscienceTA/PublishingImages/Chrome/HealthyMinds.png&quot; /&gt;&lt;/td&gt;&lt;td valign=&quot;top&quot;&gt;&lt;span style=&quot;font-size:20px;font-color:#16469a;&quot;&gt;&lt;b&gt;Community Programs&lt;/b&gt;&lt;/span&gt;&lt;br /&gt;&lt;br /&gt;</xsl:variable>

		<xsl:variable name="tableClose">&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;</xsl:variable>

		<xsl:if test="count(preceding-sibling::*)=0">
			<xsl:value-of select="$tableOpen" disable-output-escaping="yes" />		
		</xsl:if>

		<div id="BiotechnewsStyle" class="pcd">        
			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" class="titel">
				<xsl:value-of select="$DisplayTitle"/>
			</a>   	         
		</div>

		<xsl:if test="count(following-sibling::*)=0">
			<xsl:value-of select="$tableClose" disable-output-escaping="yes" />	
		</xsl:if>

	</xsl:template>


<!-- End of item styles for Neuroscience TA -->

</xsl:stylesheet>